flutter_async_cache library

Classes

CacheConfig
Configuration for the cache system
CacheEntry<T>
Represents a single entry in the cache
CacheEvent
Cache events
CacheManager
Main cache manager that handles all caching operations
CacheStatistics
Cache statistics
CacheStrategy
Abstract base class for cache strategies
CacheStrategyFactory
Factory for creating cache strategies
FIFOStrategy
First In First Out (FIFO) cache strategy
LFUStrategy
Least Frequently Used (LFU) cache strategy
LRUStrategy
Least Recently Used (LRU) cache strategy
NetworkConnectivity
Monitors network connectivity status
RandomStrategy
Random cache strategy
TimeBasedStrategy
Time-based cache strategy

Enums

EvictionStrategy
Strategy for evicting entries when the cache is full

Extensions

ConnectivityResultExtension on ConnectivityResult
Extension to provide more readable connectivity status

Exceptions / Errors

CacheEntryNotFoundException
Thrown when trying to access a cache entry that doesn't exist
CacheException
Thrown when a cache operation fails
CacheExpiredException
Thrown when a cache entry has expired
CacheFullException
Thrown when the cache is full and no entries can be evicted
NoNetworkException
Thrown when there's no network connectivity and offline mode is not enabled